from .meta import (
    content_proper,
    initial_data,
    ponencia_slice,
    sanitize_field,
    with_unique_fn,
)


def legacy_data(text: str, idx: str) -> dict:
    """Use the supplied parameters to combine data dictionaries.

    Args:
        text (str): The unprocessed string representing the ponencia
        idx (str): The url identifier

    Returns:
        dict: A dictionary with keys acceptable to scrapy processing pipeline..
    """
    case_details = initial_data(text, idx)
    ponencia_details = content_proper(case_details["ponencia"])
    data = case_details | ponencia_details

    data["ponencia"] = ponencia_slice(data)
    data["ponencia"] = with_unique_fn(data["ponencia"])

    data = sanitize_field(data, "ponencia")
    data = sanitize_field(data, "annex")
    data = sanitize_field(data, "fallo")
    data = sanitize_field(data, "voting")
    data = sanitize_field(data, "ruling")

    # data_complete["ponencia"] = transform(data_complete["ponencia"]) TODO: causes TypeError on BAD DATE
    return data
